@@ -25,7 +25,7 @@ class FingerTremoloFlag2(TreeChordFlag2):
         self.slur = None
 
     def __deepcopy__(self, memodict={}):
-        return self.__class__(tremolo_chord=self.tremolo_chord.tremolo_flag_copy(), number=self.number, mode=self.mode)
+        return self.__class__(tremolo_chord=self.tremolo_chord.copy_tremolo_flag(), number=self.number, mode=self.mode)
 
     @property
     def mode(self):
@@ -71,7 +71,7 @@ class FingerTremoloFlag2(TreeChordFlag2):
 
         self.tremolo_chord.quarter_duration = chord.quarter_duration
 
-        # self.tremolo_chord.parent_voice = chord.parent_voice
+        # self.tremolo_chord.parent_tree_part_voice = chord.parent_tree_part_voice
         self.tremolo_chord.parent_beat = chord.parent_beat
         # v = chord.get_children_by_type(Voice)[0]
         #
@@ -90,7 +90,7 @@ class FingerTremoloFlag2(TreeChordFlag2):
         else:
             chord.add_words('\uF417', font_family='bravura', font_size=16, relative_x=30, relative_y=-50)
             chord.set_tie_orientation('under')
-        self.tremolo_chord.parent_voice = chord.parent_voice
+        self.tremolo_chord.parent_tree_part_voice = chord.parent_tree_part_voice
         self.tremolo_chord.parent_beat = chord.parent_beat
         v = chord.get_children_by_type(Voice)[0]
         if not self.tremolo_chord.get_children_by_type(Voice):
