@@ -17,7 +17,7 @@ class Test(TestCase):
         self.score.set_time_signatures(quarter_durations=sf.quarter_duration)
 
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
         result_path = path + '_test_1'
         self.score.write(path=result_path)
@@ -28,7 +28,7 @@ class Test(TestCase):
         self.score.set_time_signatures(times={1: (3, 4), 5: (2, 4)})
 
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
         result_path = path + '_test_2'
         self.score.write(path=result_path)
@@ -39,7 +39,7 @@ class Test(TestCase):
         self.score.set_time_signatures(quarter_durations=[8, 3, 5, 4, 11, 3])
 
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
         result_path = path + '_test_3'
         self.score.write(path=result_path)
@@ -50,7 +50,7 @@ class Test(TestCase):
         self.score.set_time_signatures(quarter_durations=[8, 3, 5, 4, 11, 3], times={1: (3, 4)})
 
         v = sf.to_stream_voice(1)
-        v.add_to_score(self.score, 1, 1)
+        v.add_to_score(self.score)
 
         result_path = path + '_test_4'
         self.score.write(path=result_path)
